<?php
/*
Plugin Name: Multisite user registration manager
Description: Systém žádostí o registraci a jejich vyřizování. Superadministrátorský plugin. <strong>Vyvinuto a určeno pro blogosphere.cz</strong>
Version: 1.4
Author: Zaantar
Author URI: http://zaantar.eu
Plugin URI: http://zaantar.eu/index.php?page=murm
License: GPL2
*/

/*
    Copyright 2010-2011 Zaantar (email: zaantar@gmail.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

//require_once(ABSPATH . WPINC . '/registration.php');

include( 'Akismet.class.php' );

/* ************************************************************************* *\
	ADMIN MENU
\* ************************************************************************* */


add_action( 'admin_menu','murm_admin_menu' );
add_action( 'network_admin_menu','murm_network_admin_menu' );

function murm_admin_menu() {
	add_submenu_page( 'options-general.php','Nastavení Multisite user registration management', 'MURM', 'manage_options', 
		'murm-options', 'murm_options_page' );
	if( murm_is_active() ) {
		add_submenu_page( 'users.php', 'Žádosti o registrace na tomto blogu', 'Žádosti o registrace', 'manage_options', 
			'murm-moderation', 'murm_moderation_page' );
	}
	
	/*$user = wp_get_current_user();*/
	
}


function murm_network_admin_menu() {
	add_submenu_page( 'users.php', 'Správa žádostí MURM', 'Žádosti MURM', 'manage_network_users', 
		'murm-superadmin', 'murm_superadmin_page' );
}


/* ************************************************************************* *\
	MISCELLANEOUS & DEBUG
\* ************************************************************************* */


function murm_nag( $message ) {
	echo( '<div id="message" class="updated"><p>'.$message.'</p></div>' );
}

function murm_nagerr( $message ) {
	echo( '<div id="message" class="error"><p>'.$message.'</p></div>' );
}


function murm_log( $message ) {
	if( is_user_logged_in() ) {
		$user = wp_get_current_user();
		$user = $user->user_login;
	} else {
		$user = '*visitor*';
	}
	$date = date( 'Y-m-d H:i:s' );
	$blogid = get_current_blog_id();
	switch_to_blog( $blogid );
	$blogname = get_bloginfo( 'siteurl' );
	restore_current_blog();
	$message = '***  '.$date.', '.$user.' @ '.$blogid.' ('.$blogname.'):: '.$message."\n\n";
	if( defined( 'WLS' ) && wls_is_registered( 'murm' ) ) {
		wls_simple_log( 'murm', $message );
	} else {
		//fallback
		murm_log_to_file( $message );
	}
}

function murm_log_to_file( $message ) {
	$filename = dirname(__FILE__).'/log.txt';
	$file = fopen( $filename, 'ä́' );
	fwrite( $file, $message );
	fclose( $file );
}

/* ************************************************************************* *\
	OPTIONS
\* ************************************************************************* */

define( 'MURM_OPT_ACTIVE', 'murm_is_active' );
define( 'MURM_OPT_SHOWNAG', 'murm_show_nag' );
define( 'MURM_OPT_INSTALLED', 'murm_installed' );
define( 'MURM_OPT_MAIL_ADMIN_ON_REQUEST', 'murm_mail_admin_on_request' );
define( 'MURM_OPT_ANTISPAM', 'murm_antispam' );
define( 'MURM_OPT_AKISMET_KEY', 'murm_akismet_key' );



function murm_options_page() {
	murm_nag( 'Tento plugin je ve vývoji. Pokud se vyskytnou jakékoliv problémy nebo nejasnosti, kontaktujte <a href="mailto:zaantar@zaantar.eu">vývojáře</a>. Díky za pochopení.' );
	if( isset($_REQUEST['action']) ) {
        $action = $_REQUEST['action'];
    } else {
        $action = 'default';
    }
    
    switch( $action ) {
    case 'uninstall':
    	murm_options_page_uninstall();
    	murm_options_page_default();
    	break;
    case 'update':
    	murm_options_page_update();
    	murm_options_page_default();
    	break;
    case 'wls-register':
    	wls_register( 'murm', 'Logy provozu pluginu Multisite User Registration Management.' ); //TODO return value check
    	murm_options_page_default();
    	break;
    case 'wls-unregister':
    	wls_unregister( 'murm' ); //TODO return value check
    	murm_options_page_default();
    	break;
    default:
    	murm_options_page_default();
    	break;
    }
}



function murm_options_page_default() {
	?>
	<div class="wrap">
        <h2>Nastavení Multisite user registration management</h2>
		<p>
			Zde můžete aktivovat systém pro zasílání a vyřizování žádostí o registraci na vašem blogu. Do článku nebo stránky můžete následně vložit shortcode <code>[murm-form]</code>, místo kterého se pak zobrazí formulář pro zasílání žádostí. Máte-li blog uzamčen například pluginem Members Only, je velmi vhodné, aby se tento shortcode nacházel na uvítací stránce, na kterou jsou přesměrovávání uživatelé bez povoleného přístupu.
		</p>
		<p>
			V případě otázek, problémů nebo požadavků na další funkcionalitu se neváhejte obrátit na <a href="mailto:zaantar@zaantar.eu">vývojáře</a>.
		</p>
		<form method="post" action="options-general.php?page=murm-options">
            <input type="hidden" name="action" value="update" />
            <table class="form-table">
                <tr valign="top">
                	<th><label for="murm_active">Aktivovat na tomto blogu</label></th>
                	<td>
                		<input type="checkbox" name="murm_active" <?php if( murm_is_active() ) { echo( 'checked="checked"' ); } ?> />
                	</td>
                </tr>
              	<tr valign="top">
                	<th><label for="murm_shownag">Zobrazit upozornění v administraci při nevyřízených registracích</label></th>
                	<td>
                		<input type="checkbox" name="murm_shownag" <?php if( murm_is_nag() ) { echo( 'checked="checked"' ); } ?> />
                	</td>
                </tr>
                <tr valign="top">
                	<th><label for="murm_mail_admin_on_request">Zaslat e-mail při nové žádosti o registraci</label></th>
                	<td>
                		<input type="checkbox" name="murm_mail_admin_on_request" <?php if( murm_is_mail_admin_on_request() ) { echo( 'checked="checked"' ); } ?> />
                	</td>
                </tr>
                <tr valign="top">
                	<th><label for="murm_antispam">Zapnout ochranu proti spamu</label></th>
                	<td>
                		<input type="checkbox" name="murm_antispam" <?php if( murm_is_antispam() ) { echo( 'checked="checked"' ); } ?> />
                	</td>
                </tr>
                <tr valign="top">
                	<th><label for="murm_akismet_key">API klíč pro Akismet (pro funkčnost spamové ochrany)</label></th>
                	<td>
                		<input type="text" name="murm_akismet_key" value="<?php echo get_option( MURM_OPT_AKISMET_KEY, '' ); ?>" />
                	</td>
                </tr>
			</table>
			<p class="submit">
	            <input type="submit" value="Uložit nastavení" />    
	        </p>        
        </form>
        <h3>Odinstalace z tohoto blogu</h3>
        <p>
        	Kliknutím na následující tlačítko deaktivujete MURM a odstraníte všechny žádosti o registrace, které čekají na vaše schválení. Nijak to neovlivní žádosti, které již byly předány správci sítě.
        </p>
        <form method="post" action="options-general.php?page=murm-options">
        	<input type="hidden" name="action" value="uninstall" />
        	<p class="submit">
	            <input type="submit" value="Odinstalovat MURM z blogu" />    
	        </p> 
        </form>
        <?php 
        	if( defined( 'WLS' ) && is_super_admin() ) {
        		?>
        		<h3>Registrace do systémového logu WLS</h3>
        		<p>Byl detekován nainstalovaný plugin Wordpress Logging Service.</p>
        		<?php
        			if( !wls_is_registered( 'murm' ) ) {
        				?>
						<form method="post" action="options-general.php?page=murm-options">
							<input type="hidden" name="action" value="wls-register" />
							<p class="submit">
								<input type="submit" value="Registrovat MURM do WLS" />    
							</p> 
						</form>
						<?php
					} else {
						?>
						<form method="post" action="options-general.php?page=murm-options">
							<input type="hidden" name="action" value="wls-unregister" />
							<p class="submit">
								<input type="submit" value="Odregistrovat MURM z WLS a smazat všechny logy" />    
							</p> 
						</form>
						<?php
					}
				?>
				
				<?php
        	}
        ?>
	</div>
	<?php
}



function murm_options_page_uninstall() {

	murm_log( 'Uninstalling MURM from this blog.' );
	
	$dbok = murm_drop_blog_table();
	
	if( !$dbok ) {
		murm_nagerr( 'Při odinstalaci MURM z vašeho blogu došlo k chybě v databázi. Prosím kontaktujte vývojáře.' );
		murm_log( 'ERROR while uninstalling MURM' );
		return;
	}
	
	update_option( MURM_OPT_INSTALLED, false );
	update_option( MURM_OPT_ACTIVE, false );
	
	murm_nag( 'MURM byl úspěšně odinstalován z vašeho blogu.');
	murm_log( 'Successfully uninstalled.' );
}


function murm_options_page_update() {

	murm_log( 'murm_options_page_update() begin' );
	
	$active = isset( $_POST['murm_active'] );
	$shownag = isset( $_POST['murm_shownag'] );
	$mail_admin_on_request = isset( $_POST['murm_mail_admin_on_request'] );
	$antispam = isset( $_POST['murm_antispam'] );
	$akismet_key = $_POST['murm_akismet_key'];
	
	update_option( MURM_OPT_ACTIVE, $active );
	update_option( MURM_OPT_SHOWNAG, $shownag );
	update_option( MURM_OPT_MAIL_ADMIN_ON_REQUEST, $mail_admin_on_request );
	update_option( MURM_OPT_ANTISPAM, $antispam );
	update_option( MURM_OPT_AKISMET_KEY, $akismet_key );


	if( $active && !murm_is_installed() ) {
		murm_install_on_blog();
	}

	murm_log( 'murm_options_page_update() end' );
	
	murm_nag( 'Nastavení byla úspěšně uložena.' );
}



function murm_is_active() {
	if( get_option( MURM_OPT_ACTIVE, false ) ) {
		return true;
	} else {
		return false;
	}
}


function murm_is_nag() {
	if( get_option( MURM_OPT_SHOWNAG, false ) ) {
		return true;
	} else {
		return false;
	}
}


function murm_is_installed() {
	if( get_option( MURM_OPT_INSTALLED, false ) ) {
		return true;
	} else {
		return false;
	}
}


function murm_is_mail_admin_on_request() {
	if( get_option( MURM_OPT_MAIL_ADMIN_ON_REQUEST, false ) ) {
		return true;
	} else {
		return false;
	}
}


function murm_is_antispam() {
	if( get_option( MURM_OPT_ANTISPAM, false ) ) {
		return true;
	} else {
		return false;
	}
}

function murm_install_on_blog() {
	murm_log( 'installing MURM on this blog' );
	
	$dbok = murm_create_tables();
	
	if( $dbok ) {
		update_option( MURM_OPT_INSTALLED, true );
		murm_nag( 'MURM byl na vašem blogu úspěšně zaveden.' );
		murm_log( 'installed successfully' );
	} else {
		murm_nagerr( 'Při zavádění MURM na vašem blogu došlo k chybě. Kontaktujte vývojáře.' );
		murm_log( 'error while installing' );
	}
}


/* ************************************************************************* *\
	MURM DATABASE ACCESS
\* ************************************************************************* */


function murm_create_tables() {
	global $wpdb;
	
	$site_query = '
		CREATE TABLE IF NOT EXISTS '.$wpdb->base_prefix.'murm_requests (
			id INT NOT NULL AUTO_INCREMENT,
			blog_id INT,
			approved_by INT,
			username VARCHAR( 60 ),
			displayname VARCHAR( 50 ),
			url VARCHAR( 100 ),
			email VARCHAR( 100 ),
			message TEXT,
			UNIQUE ( id ),
            PRIMARY KEY ( id )
        )';
        
	$serr = $wpdb->query( $wpdb->prepare( $site_query ) );
        
	$blog_query = '
		CREATE TABLE IF NOT EXISTS '.$wpdb->prefix.'murm_requests (
			id INT NOT NULL AUTO_INCREMENT,
			username VARCHAR( 60 ),
			displayname VARCHAR( 50 ),
			url VARCHAR( 100 ),
			email VARCHAR( 100 ),
			message TEXT,
			UNIQUE ( id ),
            PRIMARY KEY ( id )
        )';
	
	$berr = $wpdb->query( $wpdb->prepare( $blog_query ) );
	
	if( ( $serr===FALSE ) or ( $berr===FALSE ) ) {
		return false;
	} else {
		return true;
	}
}


function murm_drop_blog_table() {
	global $wpdb;
	$query = 'DROP TABLE '.$wpdb->prefix.'murm_requests';
	$derr = $wpdb->query( $wpdb->prepare( $query ) );

	if( $derr === FALSE ) {
		return false;
	} else {
		return true;
	}
}


function murm_delete_admin_request( $request_id ) {
	global $wpdb;
	
	$query = '
		DELETE FROM '.$wpdb->prefix.'murm_requests
		WHERE id='.$request_id;
		
	$dok = $wpdb->query( $wpdb->prepare( $query ) );
	
	if( $dok === FALSE ) {
		return false;
	} else {
		return true;
	}
}


function murm_delete_superadmin_request( $request_id ) {
	global $wpdb;
	
	$query = '
		DELETE FROM '.$wpdb->base_prefix.'murm_requests
		WHERE id='.$request_id;
		
	$dok = $wpdb->query( $wpdb->prepare( $query ) );
	
	if( $dok === FALSE ) {
		return false;
	} else {
		return true;
	}
}


function murm_get_admin_request( $request_id ) {
	global $wpdb;
	
	$query = '
			SELECT *
			FROM '.$wpdb->prefix.'murm_requests
			WHERE id='.$request_id;
	
	$result = $wpdb->get_row( $wpdb->prepare( $query ) );
	
	return $result;
}


function murm_get_superadmin_request( $request_id ) {
	global $wpdb;
	
	$query = '
			SELECT *
			FROM '.$wpdb->base_prefix.'murm_requests
			WHERE id='.$request_id;
			
	$result = $wpdb->get_row( $wpdb->prepare( $query ) );
	
	return $result;
}


function murm_has_admin_requests() {
	global $wpdb;
	
	$query = '
		SELECT COUNT(*)
		FROM '.$wpdb->prefix.'murm_requests';
		
	$count = $wpdb->get_var( $wpdb->prepare( $query ) );
	
	if( $count > 0 ) {
		return true;
	} else {
		return false;
	}
}

/* ************************************************************************* *\
	SHORTCODE
\* ************************************************************************* */

add_shortcode( 'murm-form', 'murm_shortcode_handler' );

function murm_shortcode_handler() {
	if( !murm_is_active ) {
		//TODO
		murm_log( 'shortcode used while murm inactive' );
		return;
	}

	if( isset($_REQUEST['action']) ) {
        $action = $_REQUEST['action'];
    } else {
        $action = 'default';
    }
    
    switch( $action ) {
    case 'commit':
    	return murm_shortcode_handler_commit();
    	break;
    default:
    	return murm_shortcode_handler_default();
    }
}


function murm_shortcode_handler_default() {
	if( is_user_logged_in() ) {
		return murm_shortcode_handler_logged();
	} else {
		return murm_shortcode_handler_new();
	}
}


function murm_shortcode_handler_new() {
	$code = '
	<div id="murm">
		<form method="post" action="'.get_permalink().'">
            <input type="hidden" name="action" value="commit" />
            <table class="form-table">
                <tr>
                	<th><label for="username">Uživatelské jméno</label></th>
                	<td>
                		<input type="text" name="username" />
                	</td>
                </tr>
                <tr valign="top">
                	<td colspan="2"><small>Povinný údaj. Smí obsahovat pouze malá písmena bez diakritiky a čísla a musí být dlouhé alespoň čtyři znaky.</small></td>
                </tr>
                <tr>
                	<th><label for="email">E-mail</label></th>
                	<td>
                		<input type="text" name="email" />
                	</td>
                </tr>
                <tr valign="top">
                	<td colspan="2"><small>Povinný údaj</small></td>
                </tr>
                <tr>
                	<th><label for="displayname">Zobrazované jméno</label></th>
                	<td>
                		<input type="text" name="displayname" />
                	</td>
                </tr>
                <tr>
                	<th><label for="url">Váš web</label></th>
                	<td>
                		<input type="text" name="url" />
                	</td>
                </tr>
                <tr valign="top">
                	<th><label for="message">Zpráva pro vlastníka blogu</label></th>
                	<td>
                		<textarea name="message" wrap="soft"></textarea>
                	</td>
                </tr>
                <tr valign="top">
                	<td colspan="2"><small>Pokud se s vlastníkem tohoto blogu neznáte, možná pomůže, když o sobě něco napíšete. Užitečná také bývá informace, jak jste na tento blog narazili.</small></td>
                </tr>
			</table>
			<p class="submit">
	            <input type="submit" value="Odeslat žádost" />    
	        </p> 
		</form>
	</div>';
	return $code;
}


function murm_shortcode_handler_logged() {
	$user = wp_get_current_user();
	$code = '
		<div id="murm">
			<p>
				Momentálně jste přihlášeni jako uživatel <strong>'.$user->user_login.'</strong>. Chcete-li pod tímto jménem požádat o registraci na tomto blogu, stačí kliknout tlačíto pro odeslání žádosti. V opačném případě je nutno se nejdříve <a href="'.wp_logout_url( get_permalink() ).'">odhlásit</a>.
			</p>
			<form method="post" action="'.get_permalink().'">
		        <input type="hidden" name="action" value="commit" />
		        <input type="hidden" name="username" value="'.$user->user_login.'" />
		        <input type="hidden" name="email" value="'.$user->user_email.'" />
		        <table class="form-table">
					<tr valign="top">
		            	<th><label for="message">Zpráva pro vlastníka blogu</label></th>
		            	<td>
		            		<textarea name="message" wrap="soft"></textarea>
		            	</td>
		            </tr>
		            <tr valign="top">
		            	<td colspan="2"><small>Pokud se s vlastníkem tohoto blogu neznáte, možná pomůže, když o sobě něco napíšete. Užitečná také bývá informace, jak jste na tento blog narazili.</small></td>
		            </tr>
                </table>
				<p class="submit">
			        <input type="submit" value="Odeslat žádost" />    
			    </p> 
			</form>
		</div>';
	return $code;
}


function murm_shortcode_handler_commit() {
	global $wpdb;
	
	$username = $_POST['username'];
	$displayname = $_POST['displayname'];
	$email = $_POST['email'];
	$url = $_POST['url'];
	$message = $_POST['message'];
	
	murm_log( 'registration request: "'.$username.'", "'.$displayname.'", "'.$email.'", "'.$url.'", "'.$message.'"' );
	$username = strtolower( $username );
	
	if( !murm_is_username_correct( $username ) ) {
		murm_log( 'rr denied - incorrect username' );
		return '<p class="error">Chyba! Uživatelské jméno musí být dlouhé alespoň čtyři znaky a smí obsahovat pouze malá písmena bez diakritiky a číslice.</p>';
	}
	
	if( !murm_is_email_correct( $email ) ) {
		murm_log( 'rr denied - incorrect email' );
		return '<p class="error">Chyba! Musí být zadána platná e-mailová adresa.</p>';
	}
	
	if( !murm_is_valid_combination( $username, $email ) ) {
		murm_log( 'rr denied - invalid combination' );
		return '<p class="error">Chyba! Kombinace uživatelského jména a e-mailu není platná (alespoň jeden z údajů je již v síti již použit v jiné kombinaci).</p>';
	}
	
	if( murm_is_duplicate_request( $username, $email ) ) {
		murm_log( 'rr denied - duplicate request' );
		return '<p class="error">Chyba! Žádost s tímto uživatelským jménem anebo e-mailem již byla zaznamenána.</p>';
	}
	
	if( murm_is_spam( $username, $email, $url, $message ) ) {
		murm_log( 'rr denied - recognized as spam' );
		return '<p class="error">Chyba! Vaše žádost byla vyhodnocena jako spam systémem Akismet. Pokud spam není, kontaktujte vlastníka blogu nebo správce sítě.</p>';
	}
		
	$iok = $wpdb->insert( $wpdb->prefix.'murm_requests', 
		array(
			'username' => $username,
			'displayname' => $displayname,
			'email' => $email,
			'url' => $url,
			'message' => $message
		) );
	
	$rid = $wpdb->insert_id;
	
	if( !$iok ) {
		murm_log( 'error while commiting rr' );
		return '<p class="error">Při ukládání požadavku do databáze došlo k chybě. Kontaktujte, prosím, <a href="mailto:zaantar@zaantar.eu">vývojáře</a>.</p>';
	} 
	
	if( murm_is_mail_admin_on_request() ) {
		murm_log( 'sending information about new request to blog admin' );
		$request = murm_get_admin_request( $rid );
		//echo 'rid:'.$rid.';'.$request->email;
		$subject = murm_parse_mail( MURM_MAIL_ADMIN_NEW_REQUEST_SUBJECT, $blog_id, $request );
		$message = murm_parse_mail( MURM_MAIL_ADMIN_NEW_REQUEST_MESSAGE, $blog_id, $request );	
		wp_mail( get_bloginfo( 'admin_email' ) , $subject, $message );
	}
	
	murm_log( 'rr successfully commited to database' );
	return '<p>Vaše žádost byla zaznamenána. Nyní prosíme o trpělivost, o dalším vývoji budete informováni pomocí e-mailu.';
}


function murm_is_valid_combination( $username, $email ) {
	$uex = username_exists( $username );
	$eex = email_exists( $email );
	
	if( ($uex && !$eex) or (!$uex && $eex) ) {
		return false;
	} else if( $uex ) {
		$user = get_userdatabylogin( $username );
		if( $user->user_email != $email ) {
			return false;
		}
	}
	
	return true;
}


function murm_is_duplicate_request( $username, $email ) {
	global $wpdb, $blog_id;
	
	$blog_query = '
		SELECT COUNT(*)
		FROM '.$wpdb->prefix.'murm_requests
		WHERE (
			username=\''.$username.'\' 
			OR email=\''.$email.'\'
			)';
	
	$blog_duplicates = $wpdb->get_var( $wpdb->prepare( $blog_query ) );
			
	$net_query = '
		SELECT COUNT(*)
		FROM '.$wpdb->base_prefix.'murm_requests
		WHERE (
			username=\''.$username.'\'
			OR email=\''.$email.'\'
			)
			AND blog_id = '.$blog_id;
	
	$net_duplicates = $wpdb->get_var( $wpdb->prepare( $net_query ) );
	
	return ( ( $blog_duplicates != 0 ) or ( $net_duplicates != 0 ) );
}



function murm_is_username_correct( $username ) {
	$lenok = ( strlen( $username ) >= 4 );
	$charsok = preg_match( '/^[a-z0-9]+$/u', $username );
	return $lenok && $charsok && validate_username( $username );
}


function murm_is_email_correct( $email ) {
	return is_email( $email );
}


function murm_is_spam( $username, $email, $url, $content ) {
	if( !murm_is_antispam() ) {
		return false;
	}

	$key = get_option( MURM_OPT_AKISMET_KEY, '' );
	
	$akismet = new MurmAkismet( home_url() ,$key);
	$akismet->setCommentAuthor( $username );
	$akismet->setCommentAuthorEmail( $email );
	$akismet->setCommentAuthorURL( $url );
	$akismet->setCommentContent( $content );
	$akismet->setPermalink( get_permalink() );

	return $akismet->isCommentSpam();
}

/* ************************************************************************* *\
	MODERATION
\* ************************************************************************* */


function murm_moderation_page() {
	if( !murm_is_active() ) {
		return;
	}
	
	murm_nag( 'Tento plugin je ve vývoji. Pokud se vyskytnou jakékoliv problémy nebo nejasnosti, kontaktujte <a href="mailto:zaantar@zaantar.eu">vývojáře</a>. Díky za pochopení.' );

	if( isset($_REQUEST['action']) ) {
        $action = $_REQUEST['action'];
    } else {
        $action = 'default';
    }

	switch( $action ) {
	case 'approve':
		murm_moderation_page_approve();
		murm_moderation_page_default();
		break;
	case 'deny':
		murm_moderation_page_deny();
		murm_moderation_page_default();
		break;
	case 'confirm-delete':
		murm_moderation_page_confirm_delete();
		break;
	case 'delete':
		murm_moderation_page_delete();
		murm_moderation_page_default();
		break;
	default:
		murm_moderation_page_default();
	}
}


function murm_moderation_page_default() {
	global $wpdb;
	
	$query = '
		SELECT id, username, email, displayname, url, message
		FROM '.$wpdb->prefix.'murm_requests';
		
	$requests = $wpdb->get_results( $wpdb->prepare( $query ) );
	
	?>
	<div class="wrap">
		<h2>Žádosti o registrace na tomto blogu</h2>
		<table class="widefat" cellspacing="0">
		    <thead>
		        <tr>
		            <th scope="col" class="manage-column">id</th>
		            <th scope="col" class="manage-column">Uživatelské jméno</th>
		            <th scope="col" class="manage-column">E-mail</th>
		            <th scope="col" class="manage-column">Zobrazované jméno</th>
		            <th scope="col" class="manage-column">Web</th>
		            <th scope="col" class="manage-column">Zpráva pro vlastníka blogu</th>
		            <th scope="col" class="manage-column">Akce</th>
				</tr>
			</thead>
			<tfoot>
		        <tr>
		            <th scope="col" class="manage-column">id</th>
		            <th scope="col" class="manage-column">Uživatelské jméno</th>
		            <th scope="col" class="manage-column">E-mail</th>
		            <th scope="col" class="manage-column">Zobrazované jméno</th>
		            <th scope="col" class="manage-column">Web</th>
		            <th scope="col" class="manage-column">Zpráva pro vlastníka blogu</th>
		            <th scope="col" class="manage-column">Akce</th>
				</tr>
			</tfoot>
			<?php
				foreach( $requests as $request ) {
					?>
					<tr>
						<td><?php echo $request->id; ?></td>
						<td><?php echo $request->username; ?></td>
						<td><?php echo $request->email; ?></td>
						<td><?php echo $request->displayname; ?></td>
						
						<td><?php echo $request->url; ?></td>
						<td><?php echo $request->message; ?></td>
						<td>
							<a href="users.php?page=murm-moderation&action=approve&id=<?php echo $request->id; ?>">Povolit</a>
							&nbsp;&nbsp;
							<a href="users.php?page=murm-moderation&action=deny&id=<?php echo $request->id; ?>">Zamítnout</a>
							&nbsp;&nbsp;
							<a href="users.php?page=murm-moderation&action=confirm-delete&id=<?php echo $request->id; ?>">Odstranit</a>
						</td>
					</tr>
				
					<?php
				}
			?>
		</table>
	</div>
	<?php
}


function murm_moderation_page_approve() {
	global $wpdb, $blog_id;
	
	$rid = $_REQUEST['id'];
	
	murm_log( 'admin approving registration request '.$rid );
	
	$request = murm_get_admin_request( $rid );
	
	if( $request == NULL ) {
		murm_nagerr( 'Žádost č. '.$rid.' nebyla v databázi nalezena, nelze ji tedy potvrdit. Pokud si myslíte, že se jedná o chybu, kontaktujte vývojáře.' );
		murm_log( 'error - rr '.$rid.' doesnt exist' );
		return;
	}
	
	$insert_data = array(
		'blog_id' => $blog_id,
		'approved_by' => get_current_user_id(),
		'username' => $request->username,
		'email' => $request->email,
		'displayname' => $request->displayname,
		'url' => $request->url,
		'message' => $request->message
	);
	
	$iok = $wpdb->insert( $wpdb->base_prefix.'murm_requests', $insert_data );
	
	if( !$iok ) {
		murm_nagerr( 'Při vkládání záznamu do databáze došlo k chybě, žádost č. '.$rid.' nemohla být vyřízena. Kontaktujte, prosím, vývojáře.' );
		murm_log( 'error while inserting to superadmin moderation table: '.print_r( $insert_data, TRUE ) );
		return;
	}
	
	//$wpdb->print_error();

	murm_log( 'sending mail to superadmin' );
	$subject = murm_parse_mail( MURM_MAIL_SUPERADMIN_NEW_REQUEST_SUBJECT, $blog_id, $request );
	$message = murm_parse_mail( MURM_MAIL_SUPERADMIN_NEW_REQUEST_MESSAGE, $blog_id, $request );
	wp_mail( get_site_option( 'admin_email' ), $subject, $message );
	
	$dok = murm_delete_admin_request( $rid );
	
	if( $dok ) {
		murm_nag( 'Žádost č. '.$rid.' byla potvrzena a předána k vyřízení správci sítě. O dalším vývoji budete informováni e-mailem. Prosíme o trpělivost.' );
		murm_log( 'rr approved by admin' );
	} else {
		murm_nagerr( 'Při odstraňování záznamu z databáze došlo k chybě, žádost č. '.$rid.' nemohla být korektně vyřízena. Kontaktujte, prosím, vývojáře.' );
		murm_log( 'error while removing rr from db' );
	}
}


function murm_moderation_page_deny() {
	$rid = $_REQUEST['id'];
	
	murm_log( 'admin denying registration request '.$rid );
	
	$request = murm_get_admin_request( $rid );
	
	if( $request == NULL ) {
		murm_nagerr( 'Žádost č. '.$rid.' nebyla v databázi nalezena, nelze ji tedy zamítnout. Pokud si myslíte, že se jedná o chybu, kontaktujte vývojáře.' );
		murm_log( 'error - rr '.$rid.' doesnt exist' );
		return;
	}
	
	murm_log( 'sending mail to requesting user' );
	$subject = murm_parse_mail( MURM_MAIL_DENY_FROM_ADMIN_SUBJECT, $blog_id, $request );
	$message = murm_parse_mail( MURM_MAIL_DENY_FROM_ADMIN_MESSAGE, $blog_id, $request );	
	wp_mail( $request->email, $subject, $message );
	
	$dok = murm_delete_admin_request( $rid );
	
	if( $dok ) {
		murm_nag( 'Žádost o registraci č. '.$rid.' byla úspěšně zamítnuta. Žádajícímu byl odeslán e-mail s oznámením.' );
		murm_log( 'rr successfully denied' );
	} else {
		murm_nagerr( 'Při zamítání žádosti č. '.$rid.' došlo k chybě. Kontaktujte vývojáře.' );
		murm_log( 'error while removing rr from db' );
	}
}


function murm_moderation_page_confirm_delete() {
	$rid = $_REQUEST['id'];
	$request = murm_get_admin_request( $rid );
	?>
	<div class="wrap">
		<h2>Žádosti o registrace na tomto blogu</h2>
		<p>
			Chystáte se odstranit žádost o registraci číslo <?php echo $rid; ?> (uživatel <em><?php echo $request->username; ?></em>, e-mail <em><?php echo $request->email; ?></em>). Skutečně toto chcete provést?
		</p>
		<p>
			Při odstranění žádosti (narozdíl od jejího zamítnutí) není žádající nijak informován, tato funkce tedy slouží pouze jako stornování již jinak vyřešených žádostí anebo k odstranění spamu. Jinak byste ji využívat neměli.
		</p>
		<form method="post" action="users.php?page=murm-moderation">
			<input type="hidden" name="action" value="delete" />
			<input type="hidden" name="id" value="<?php echo $rid; ?>" />
			<p class="submit">
	            <input type="submit" value="Odstranit žádost" />    
	        </p> 
		</form>
		<p>
			&laquo; <a href="users.php?page=murm-moderation">Zpět k seznamu žádostí</a> &laquo;
		</p>
	</div>
	<?php
}


function murm_moderation_page_delete() {
	$rid = $_REQUEST['id'];

	murm_log( 'admin deleting registration request '.$rid );

	$dok = murm_delete_admin_request( $rid );
	
	if( $dok ) {
		murm_nag( 'Žádost č.'.$rid.' byla úspěšně odstraněna z databáze. Žádajícímu <b>nebyl</b> odeslán e-mail s oznámením.' );
		murm_log( 'rr '.$rid.' successfully deleted' );
	} else {
		murm_nagerr( 'Při odstraňování žídosti č.'.$rid.' z databáze došlo k chybě. Kontaktujte, prosím, vývojáře.' );
		murm_log( 'error while deleting rr '.$rid.' from db' );
	}

}



/* ************************************************************************* *\
	MAILING
\* ************************************************************************* */

// BLOG_NAME, USER_NAME, EMAIL, ADMIN_EMAIL, SITE_NAME, USER_EMAIL, SUPERADMIN_EMAIL, SITE_URL, PASSWORD, LOGIN_URL, BLOG_URL

define( 'MURM_MAIL_DENY_FROM_ADMIN_SUBJECT', '[%BLOG_NAME%] Zamítnutí žádosti o registraci' );
define( 'MURM_MAIL_DENY_FROM_ADMIN_MESSAGE', 'Litujeme, ale vaše žádost o registraci na blog %BLOG_NAME% pod uživatelským jménem %USER_NAME% byla zamítnuta vlastníkem tohoto blogu. Pro vysvětlení jej můžete kontaktovat na adrese %ADMIN_EMAIL%.

%SITE_NAME% (MURM)' );


define( 'MURM_MAIL_ADMIN_NEW_REQUEST_SUBJECT', '[%BLOG_NAME%] Nová žádost o registraci' );
define( 'MURM_MAIL_ADMIN_NEW_REQUEST_MESSAGE', 'Na vašem blogu je nová žádost o registraci uživatele %USER_NAME% (%USER_EMAIL%). Pro zodpovězení žádosti pokračujte, prosím, na %BLOG_URL%/wp-admin/users.php?page=murm-moderation.

%SITE_NAME% (MURM)' );

define( 'MURM_MAIL_SUPERADMIN_NEW_REQUEST_SUBJECT', '[%BLOG_NAME%] Nová žádost o registraci' );
define( 'MURM_MAIL_SUPERADMIN_NEW_REQUEST_MESSAGE', 'Vlastník blogu %BLOG_NAME% žádá o potvrzení registrace uživatele %USER_NAME% (%USER_EMAIL%) na svém blogu. Pro zodpovězení žádosti pokračujte, prosím, na %SITE_URL%/wp-admin/network/users.php?page=murm-superadmin.

%SITE_NAME% (MURM)' );

define( 'MURM_MAIL_DENY_FROM_SUPERADMIN_SUBJECT', '[%BLOG_NAME%] Zamítnutí žádosti o registraci' );
define( 'MURM_MAIL_DENY_FROM_SUPERADMIN_MESSAGE', 'Litujeme, ale vaše žádost o registraci na blog %BLOG_NAME% pod uživatelským jménem %USER_NAME% byla zamítnuta správcem sítě. Pro vysvětlení jej můžete kontaktovat na adrese %SUPERADMIN_EMAIL%.

%SITE_NAME% (MURM)' );


define( 'MURM_MAIL_SUPERADMIN_TO_ADMIN_DENY_SUBJECT', '[%BLOG_NAME%] Zamítnutí žádosti o registraci uživatele %USER_NAME%' );
define( 'MURM_MAIL_SUPERADMIN_TO_ADMIN_DENY_MESSAGE', 'Litujeme, ale vaše žádost o registraci uživatele %USER_NAME% na váš blog %BLOG_NAME% byla zamítnuta správcem sítě. Pro vysvětlení jej můžete kontaktovat na adrese %SUPERADMIN_EMAIL%. Žádajícímu byl odeslán e-mail s oznámením.

%SITE_NAME% (MURM)' );


define( 'MURM_MAIL_SUPERADMIN_TO_ADMIN_APPROVE_SUBJECT', '[%BLOG_NAME%] Povolení žádosti o registraci uživatele %USER_NAME%' );
define( 'MURM_MAIL_SUPERADMIN_TO_ADMIN_APPROVE_MESSAGE', 'Správce sítě potvrdil vaši žádost o registraci uživatele %USER_NAME% na vašen blogu %BLOG_NAME%. Uživateli byl poslán e-mail s přihlašovacími údaji. Pokud se vyskytnou problémy, kontaktujte správce na %SUPERADMIN_EMAIL%.

%SITE_NAME% (MURM)' );


define( 'MURM_MAIL_APPROVE_NEW_SUBJECT', '[%BLOG_NAME%] Registrace uživatelského účtu %USER_NAME%' );
define( 'MURM_MAIL_APPROVE_NEW_MESSAGE', 'Vaše registrace na blogu %BLOG_NAME% byla potvrzena. Níže naleznete údaje potřebné pro přihlášení. 

Důležité informace
(1) Tyto údaje jsou určeny výhradně vám osobně, s nikým je nesdílejte! 
(2) Budete-li v budoucnu žádat o registraci na jiném blogu v síti %SITE_NAME%, použijte přesně stejnou kombinaci uživatelského jména a e-mailu (%USER_NAME%, %USER_EMAIL%).

Pokud se vyskytnou nějaké problémy nebo nejasnosti, bez obav kontaktujte správce sítě na adrese %SUPERADMIN_EMAIL%.

Uživatelské jméno: %USER_NAME%
E-mail: %USER_EMAIL%
Heslo: %PASSWORD%

Přihlásit se můžete na adrese %LOGIN_URL%.

Vítejte!
%SITE_NAME% (MURM)' );

define( 'MURM_MAIL_APPROVE_EXISTING_SUBJECT', '[%BLOG_NAME%] Registrace uživatelského účtu %USER_NAME%' );
define( 'MURM_MAIL_APPROVE_EXISTING_MESSAGE', 'Vaše registrace na blogu %BLOG_NAME% byla potvrzena. Pro přihlášení použijte údaje, které vám k tomuto uživatelskému jménu v síti %SITE_NAME% byly zaslány dříve.

Důležité: budete-li v budoucnu žádat o registraci na jiném blogu v síti %SITE_NAME%, použijte přesně stejnou kombinaci uživatelského jména a e-mailu (%USER_NAME%, %USER_EMAIL%).

Pokud se vyskytnou nějaké problémy nebo nejasnosti, bez obav kontaktujte správce sítě na adrese %SUPERADMIN_EMAIL%.

Přihlásit se můžete na adrese %LOGIN_URL%.

Vítejte!
%SITE_NAME% (MURM)' );

function murm_parse_mail( $message, $blog_id, $request_data, $password = '[not available]' ) {
	
	switch_to_blog( $blog_id );
	
	$patterns[0] = '/%BLOG_NAME%/';
	$replacements[0] = get_bloginfo( 'name' );
	
	$patterns[1] = '/%ADMIN_EMAIL%/';
	$replacements[1] = get_bloginfo( 'admin_email' );
	
	$patterns[2] = '/%LOGIN_URL%/';
	$replacements[2] = wp_login_url();
	
	restore_current_blog();
	
	$patterns[3] = '/%USER_EMAIL%/';
	$replacements[3] = $request_data->email;

	$patterns[4] = '/%SITE_NAME%/';
	$replacements[4] = get_site_option( 'site_name' );
	
	$patterns[5] = '/%SITE_URL%/';
	$replacements[5] = get_site_url( 1 );
	
	$patterns[6] = '/%SUPERADMIN_EMAIL%/';
	$replacements[6] = get_site_option( 'admin_email' );
	
	$patterns[7] = '/%PASSWORD%/';
	$replacements[7] = $password;
	
	$patterns[8] = '/%USER_NAME%/';
	$replacements[8] = $request_data->username;	
	
	$patterns[9] = '/%BLOG_URL%/';
	$replacements[9] = get_site_url( $blog_id );
	
	$result = preg_replace( $patterns, $replacements, $message );
	return $result;
}


/* ************************************************************************* *\
	SUPERADMIN
\* ************************************************************************* */


function murm_superadmin_page() {	
	if( isset($_REQUEST['action']) ) {
        $action = $_REQUEST['action'];
    } else {
        $action = 'default';
    }

	switch( $action ) {
	case 'deny':
		murm_superadmin_page_deny();
		murm_superadmin_page_default();
		break;
	case 'approve':
		murm_superadmin_page_approve();
		murm_superadmin_page_default();
		break;
	case 'confirm-delete':
		murm_superadmin_page_confirm_delete();
		break;
	case 'delete':
		murm_superadmin_page_delete();
		murm_superadmin_page_default();
		break;
	default:
		murm_superadmin_page_default();
	}
}



function murm_superadmin_page_default() {
	global $wpdb;
	
	$query = '
		SELECT requests.id AS id, requests.username AS username, requests.email AS email, 
			requests.displayname AS displayname, requests.url AS url, requests.message AS message, 
			requests.blog_id AS blog_id, users.user_login AS approved_by, blogs.domain AS domain
		FROM ( '.$wpdb->base_prefix.'murm_requests AS requests
			JOIN  '.$wpdb->users.' AS users
			ON requests.approved_by = users.ID )
			JOIN '.$wpdb->base_prefix.'blogs AS blogs
			ON requests.blog_id = blogs.blog_id
		ORDER BY
			domain ASC,
			username ASC';
		
	$requests = $wpdb->get_results( $wpdb->prepare( $query ) );
	
	?>
	<div class="wrap">
		<h2>Žádosti MURM o registrace v síti</h2>
		<table class="widefat" cellspacing="0">
		    <thead>
		        <tr>
		            <th scope="col" class="manage-column">id</th>
		            <th scope="col" class="manage-column">Blog</th>
		            <th scope="col" class="manage-column">Uživatelské jméno</th>
		            <th scope="col" class="manage-column">E-mail</th>
		            <th scope="col" class="manage-column">Zobrazované jméno</th>
		            <th scope="col" class="manage-column">Web</th>
		            <th scope="col" class="manage-column">Zpráva pro vlastníka blogu</th>
		            <th scope="col" class="manage-column">Schváleno</th>
		            <th scope="col" class="manage-column">Akce</th>
				</tr>
			</thead>
			<tfoot>
		        <tr>
		            <th scope="col" class="manage-column">id</th>
		            <th scope="col" class="manage-column">Blog</th>
		            <th scope="col" class="manage-column">Uživatelské jméno</th>
		            <th scope="col" class="manage-column">E-mail</th>
		            <th scope="col" class="manage-column">Zobrazované jméno</th>
		            <th scope="col" class="manage-column">Web</th>
		            <th scope="col" class="manage-column">Zpráva pro vlastníka blogu</th>
		            <th scope="col" class="manage-column">Schváleno</th>
		            <th scope="col" class="manage-column">Akce</th>
				</tr>
			</tfoot>
			<?php
				foreach( $requests as $request ) {
					?>
					<tr>
						<td><?php echo $request->id; ?></td>
						<td><?php echo $request->domain; ?></td>
						<td><?php echo $request->username; ?></td>
						<td><?php echo $request->email; ?></td>
						<td><?php echo $request->displayname; ?></td>
						<td><?php echo $request->url; ?></td>
						<td><?php echo $request->message; ?></td>
						<td><?php echo $request->approved_by; ?></td>
						<td>
							<a href="users.php?page=murm-superadmin&action=approve&id=<?php echo $request->id; ?>">Povolit</a>
							&nbsp;&nbsp;
							<a href="users.php?page=murm-superadmin&action=deny&id=<?php echo $request->id; ?>">Zamítnout</a>
							&nbsp;&nbsp;
							<a href="users.php?page=murm-superadmin&action=confirm-delete&id=<?php echo $request->id; ?>">Odstranit</a>
						</td>
					</tr>
				
					<?php
				}
			?>
		</table>
	</div>
	<?php
}



function murm_superadmin_page_approve() {
	$rid = $_REQUEST['id'];

	murm_log( 'superadmin approving request '.$rid );

	$request = murm_get_superadmin_request( $rid );
	
	if( $request == NULL ) {
		murm_nagerr( 'Žádost č. '.$rid.' nebyla v databázi nalezena, nelze ji tedy povolit. Pokud si myslíte, že se jedná o chybu, kontaktujte vývojáře.' );
		murm_log( 'error - rr '.$rid.' doesnt exist' );
		return;
	}
	
	// vytvořit uživatele
	if( !murm_is_valid_combination( $request->username, $request->email ) ) {
		murm_nagerr( 'Nelze vytvořit uživatele! Kombinace jména a hesla ('.$request->username.', '.$request->email.') není použitelná.' );
		murm_log( 'error - invalid username and email combination' );
		return;	
	}
	
	if( username_exists( $request->username ) ) {
		murm_log( 'user already exists - adding to blog' );
		$user = get_userdatabylogin( $request->username );
		
		switch_to_blog( $request->blog_id );
		if( user_can( $user->ID, 'read' ) ) {
			murm_nagerr( 'Přidávaný uživatel '.$request->username.' je již na příslušném blogu zaregistrován. V registraci nelze pokračovat.' );
			murm_log( 'error - user '.$request->username.' already registered on blog '.$request->blog_id );
			return;
		} 
		restore_current_blog();
		
		add_user_to_blog( $request->blog_id, $user->ID, 'subscriber' );
		
		$user_subject = murm_parse_mail( MURM_MAIL_APPROVE_EXISTING_SUBJECT, $request->blog_id, $request );
		$user_message = murm_parse_mail( MURM_MAIL_APPROVE_EXISTING_MESSAGE, $request->blog_id, $request );	
	} else {
		$password = wp_generate_password( 12, false );
		$uid = wp_create_user( $request->username, $password, $request->email );
		$userdata = array( 
			'ID' => $uid,
			'user_url' => $request->url,
			'display_name' => $request->displayname,
		);
		wp_update_user( $userdata );
		add_user_to_blog( $request->blog_id, $uid, 'subscriber' );
		murm_log( 'creating new user '.$username.', '.$request->email.': '.print_r( $userdata, TRUE ).'; password: '.$password );
		$user_subject = murm_parse_mail( MURM_MAIL_APPROVE_NEW_SUBJECT, $request->blog_id, $request, $password );
		$user_message = murm_parse_mail( MURM_MAIL_APPROVE_NEW_MESSAGE, $request->blog_id, $request, $password );	
	}
	
	// mail uživateli
	murm_log( 'sending mail to user' );
	wp_mail( $request->email, $user_subject, $user_message );	
	
	// mail adminovi
	murm_log( 'sending mail to admin' );
	$admin_subject = murm_parse_mail( MURM_MAIL_SUPERADMIN_TO_ADMIN_APPROVE_SUBJECT, $request->blog_id, $request );
	$admin_message = murm_parse_mail( MURM_MAIL_SUPERADMIN_TO_ADMIN_APPROVE_MESSAGE, $request->blog_id, $request );	
	$admin = get_userdata( $request->approved_by );
	wp_mail( $admin->user_email, $admin_subject, $admin_message );
	
	// odstranit žádost
	$dok = murm_delete_superadmin_request( $rid );
	
	if( $dok ) {
		murm_nag( 'Žádost o registraci č. '.$rid.' byla úspěšně potvrzena. Vlastníkovi patřičného blogu byl odeslán e-mail s oznámením, žádajícímu pak e-mail s přihlašovacími údaji.' );
		murm_log( 'rr successfully approved' );
	} else {
		murm_nagerr( 'Při potvrzování žádosti č. '.$rid.' došlo k chybě v databázi. Kontaktujte vývojáře.' );
		murm_log( 'error while deleting rr from db' );
	}
}


function murm_superadmin_page_deny() {
	$rid = $_REQUEST['id'];
	
	murm_log( 'superadmin denying registration request '.$rid );
	
	$request = murm_get_superadmin_request( $rid );
	
	if( $request == NULL ) {
		murm_nagerr( 'Žádost č. '.$rid.' nebyla v databázi nalezena, nelze ji tedy zamítnout. Pokud si myslíte, že se jedná o chybu, kontaktujte vývojáře.' );
		murm_log( 'error - rr '.$rid.' doesnt exist' );
		return;
	}
	
	// mail adminovi
	murm_log( 'sending mail to admin' );
	$admin_subject = murm_parse_mail( MURM_MAIL_SUPERADMIN_TO_ADMIN_DENY_SUBJECT, $request->blog_id, $request );
	$admin_message = murm_parse_mail( MURM_MAIL_SUPERADMIN_TO_ADMIN_DENY_MESSAGE, $request->blog_id, $request );	
	$admin = get_userdata( $request->approved_by );
	wp_mail( $admin->user_email, $admin_subject, $admin_message );

	// mail žádajícímu
	murm_log( 'sending mail to user' );
	$user_subject = murm_parse_mail( MURM_MAIL_DENY_FROM_SUPERADMIN_SUBJECT, $request->blog_id, $request );
	$user_message = murm_parse_mail( MURM_MAIL_DENY_FROM_SUPERADMIN_MESSAGE, $request->blog_id, $request );	
	wp_mail( $request->email, $user_subject, $user_message );
	
	$dok = murm_delete_superadmin_request( $rid );
	
	if( $dok ) {
		murm_nag( 'Žádost o registraci č. '.$rid.' byla úspěšně zamítnuta. Žádajícímu a vlastníkovi patřičného blogu byl odeslán e-mail s oznámením.' );
		murm_log( 'rr successfully denied' );
	} else {
		murm_nagerr( 'Při zamítání žádosti č. '.$rid.' došlo k chybě. Kontaktujte vývojáře.' );
		murm_log( 'error while removing rr from db' );
	}
}


function murm_superadmin_page_confirm_delete() {
	$rid = $_REQUEST['id'];
	$request = murm_get_superadmin_request( $rid );
	?>
	<div class="wrap">
		<h2>Žádosti MURM o registrace v síti</h2>
		<p>
			Chystáte se odstranit žádost o registraci číslo <?php echo $rid; ?> (uživatel <em><?php echo $request->username; ?></em>, e-mail <em><?php echo $request->email; ?></em>). Skutečně toto chcete provést?
		</p>
		<p>
			Při odstranění žádosti (narozdíl od jejího zamítnutí) není žádající nijak informován, tato funkce tedy slouží pouze jako stornování již jinak vyřešených žádostí anebo k odstranění spamu. Jinak byste ji využívat neměli.
		</p>
		<form method="post" action="users.php?page=murm-superadmin">
			<input type="hidden" name="action" value="delete" />
			<input type="hidden" name="id" value="<?php echo $rid; ?>" />
			<p class="submit">
	            <input type="submit" value="Odstranit žádost" />    
	        </p> 
		</form>
		<p>
			&laquo; <a href="users.php?page=murm-superadmin">Zpět k seznamu žádostí</a> &laquo;
		</p>
	</div>
	<?php
}


function murm_superadmin_page_delete() {
	$rid = $_REQUEST['id'];
	
	murm_log( 'superadmin deleting registration request '.$rid );
	
	$dok = murm_delete_superadmin_request( $rid );
	
	if( $dok ) {
		murm_nag( 'Žádost č.'.$rid.' byla úspěšně odstraněna z databáze. Žádajícímu <b>nebyl</b> odeslán e-mail s oznámením.' );
		murm_log( 'rr successfully deleted' );
	} else {
		murm_nagerr( 'Při odstraňování žídosti č.'.$rid.' z databáze došlo k chybě. Kontaktujte, prosím, vývojáře.' );
		murm_log( 'error while removing rr from db' );
	}

}

/* ************************************************************************* *\
	NAG
\* ************************************************************************* */

add_action( 'admin_notices','murm_admin_notices' );

function murm_admin_notices() {
	if( !murm_is_active() ) {
		return;
	}
	
	if( murm_has_admin_requests() ) {
		murm_nag( 'Máte nevyřízené žádosti o registraci na tomto blogu. Pro jejich vyřízení pokračujte <a href="users.php?page=murm-moderation">zde</a>.' );
	}
}



?>
